package Astro::ADS;

=head1 NAME

Astro::ADS - An object orientated interface to NASA's ADS database

=head1 DESCRIPTION

This module does nothing, and is here as a placeholder in case of need. The
user interface to the goodness wrapped in the ADS package can be found in
the L<Astro::ADS::Query> module.

=head1 REVISION

$Id: ADS.pm,v 1.2 2003/07/16 18:56:43 aa Exp $

=head1 METHODS

The Astro::ADS module itself has no methods, and is just a placeholder
module, see L<Astro::ADS::Query> for the actual interface.

=head1 COPYRIGHT

Copyright (C) 2001-2003 University of Exeter. All Rights Reserved.

This program was written as part of the eSTAR project and is free software;
you can redistribute it and/or modify it under the terms of the GNU Public
License.

=head1 AUTHORS

Alasdair Allan E<lt>aa@astro.ex.ac.ukE<gt>,

=cut

use strict;
use vars qw/ $VERSION /;
$VERSION = '1.20.7'

1;                                                                  
